%global       selinuxtype  targeted
%global       modulename   smartmon

Summary:      Tools for monitoring SMART capable hard disks
Name:         smartmontools
Version:      7.3
Release:      5%{?dist}
License:      GPLv2+
URL:          https://sourceforge.net/projects/smartmontools/
Source0:      http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:      smartmontools.sysconf
Source2:      smartdnotify
Source3:      drivedb.h
Source4:      %{modulename}.te
Source5:      %{modulename}.if
Source6:      %{modulename}.fc
Source7:      %{modulename}.te.f33


Patch3001:        smartmontools-5.38-defaultconf.patch

BuildRequires:    automake make gcc-c++ util-linux groff gettext
BuildRequires:    readline-devel ncurses-devel
BuildRequires:    libselinux-devel libcap-ng-devel
BuildRequires:    systemd systemd-devel

Requires:  (%{name}-selinux if selinux-policy-%{selinuxtype})


%description
The smartmontools package contains two utility programs (smartctl
and smartd) to control and monitor storage systems using the Self-
Monitoring, Analysis and Reporting Technology System (SMART) built
into most modern ATA and SCSI hard disks. In many cases, these
utilities will provide advanced warning of disk degradation and
failure.


%package selinux
Summary:         SELinux policies for smartmontools
BuildArch:       noarch
Requires:        selinux-policy-%{selinuxtype}
Requires(post):  selinux-policy-%{selinuxtype}
BuildRequires:   selinux-policy-devel
%{?selinux_requires}
# smartd.service provided by smartmontools, is used in the post phase.
Requires(pre): %{name}

%description selinux
Custom SELinux policy module for smartmontools

%prep
%autosetup -p1
cp %{SOURCE3} .
mkdir selinux
cp -p %{SOURCE5} %{SOURCE6} selinux/
cp -p %{SOURCE7} selinux/smartmon.te


%build
autoreconf -i
%configure \
    --with-selinux \
    --with-libcap-ng=yes \
    --with-libsystemd \
    --with-systemdsystemunitdir=%{_unitdir} \
    --sysconfdir=%{_sysconfdir}/%{name}/ \
    --with-systemdenvfile=%{_sysconfdir}/sysconfig/%{name}

%make_build update-smart-drivedb
./update-smart-drivedb -s - -u sf drivedb.h ||:
cp drivedb.h ../drivedb.h ||:

%make_build CXXFLAGS="$RPM_OPT_FLAGS -fpie" LDFLAGS="-pie -Wl,-z,relro,-z,now"

make -f %{_datadir}/selinux/devel/Makefile %{modulename}.pp
bzip2 -9 %{modulename}.pp


%install
%make_install

rm -f examplescripts/Makefile*
chmod a-x -R examplescripts/*
install -D -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/smartmontools
install -D -p -m 755 %{SOURCE2} %{buildroot}/%{_libexecdir}/%{name}/smartdnotify
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/smartd_warning.d
rm -rf %{buildroot}/etc/{rc.d,init.d} %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}
install -D -m 0644 %{modulename}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.bz2

%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

if [ "$1" -le "1" ]; then
   %systemd_postun_with_restart smartd.service
fi

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{modulename}
    %selinux_relabel_post -s %{selinuxtype}
    %systemd_postun_with_restart smartd.service
fi

%preun
%systemd_preun smartd.service

%post
%systemd_post smartd.service

%postun
%systemd_postun_with_restart smartd.service

%files
%license COPYING
%doc AUTHORS ChangeLog INSTALL NEWS README
%doc TODO examplescripts smartd.conf
%dir %{_sysconfdir}/%name
%dir %{_sysconfdir}/%name/smartd_warning.d
%config(noreplace) %{_sysconfdir}/%{name}/smartd.conf
%config(noreplace) %{_sysconfdir}/%{name}/smartd_warning.sh
%config(noreplace) %{_sysconfdir}/sysconfig/smartmontools
%{_unitdir}/smartd.service
%{_sbindir}/smartd
%{_sbindir}/update-smart-drivedb
%{_sbindir}/smartctl
%{_libexecdir}/%{name}
%{_mandir}/man?/smart*.*
%{_mandir}/man?/update-smart*.*
%{_datadir}/%{name}
%{_sharedstatedir}/%{name}

%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.*
%ghost %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{modulename}

%changelog
* Mon Oct 09 2023 Wang Guodong <gordonwwang@tencent.com> - 7.3-5
- smartmontools-selinux Requires smartmontools because of post selinux

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.3-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Aug 10 2022 NewStart <os@gd-linux.com> - 7.3-1
- init package
